/*
 * Copyright(c)  2002  Rijkswaterstaat
 *                     Adviesdienst Verkeer en Vervoer
 *                     WSRA
 * File:               CRAPTAB.C
 *
 * Regelprogramma vri: Voorbeeldregeling Standaard Filemeetpunt
 *
 * datum:              29 augustus 1994
 * gewijzigd:          15 maart 2003
 * gewijzigd:          18 september 2003
 *
 * versie:             2.1
 */


#include "crtypes.h"
#include "crapcod.h"
#include "craptab.h"
#include "ccie_int.h"
#include "crapdef.h"


/*
 * =============================================================
 * declaraties t.b.v. het blokkenschema
 * =============================================================
 */

/*     BLOKKEN schema                                           */
struct BLOKKEN  BLOKKEN_tabel[] = {
/*     blok:    sg:     toewijzing:                             */
/*     BKl,     SGn,    PRIM + WSGR + ALT,                      */
       BK1,     SG02,   PRIM,
       BK2,     SG05,   PRIM,
       STOP};


/*
 * =============================================================
 * matrices
 * =============================================================
 */

/*     CONFLICT- en (garantie)ontruimingstijden matrix          */
struct CONFLICT  CONFLICT_tabel[] = {
/*                                    instellingen              */
/*                                    van de tijden:            */
/*     sg:       conflicterende sg:   GO_TIJD:  O_TIJD:         */
/*     SGn,      SGj,                 x.y,      x.y,            */
       SG02,     SG05,                2.0,      2.0,
       SG05,     SG02,                2.0,      2.0,
       STOP};

/*
 * =============================================================
 * declaraties t.b.v. de signaalgroepprocedure
 * =============================================================
 */

/*     SignaalGroep_TIJDEN tabel                                */
struct SG_TIJDEN  SG_TIJDEN_tabel[] = {
/*            instellingen van de tijden:                       */
/*     sg:    GG_TIJD:  VG_TIJD:  GGL_TIJD:  GL_TIJD:  GR_TIJD: */
/*     SGn,    x.y,      x.y,      x.y,       x.y,      x.y,    */
       SG02,   7.0,      7.0,      3.0,       3.0,      2.0,
       SG05,   7.0,      7.0,      3.0,       3.0,      2.0,
       STOP};


/*     MG_TIJDEN tabel                                          */
struct MG_TIJDEN  MG_TIJDEN_tabel[] = {
/*            instellingen (x.y of NG) van de tijden:           */
/*     sg:    MG_TIJD:  MG_TIJD1:  MG_TIJD2:  MG_TIJD3:         */
/*     SGn,    x.y,      x.y,       x.y,       x.y,             */
       SG02,  20.0,       NG,        NG,        NG,
       SG05,  20.0,       NG,        NG,        NG,
       STOP};


/*     Extra MG_TIJDEN tabel                                    */
struct E_MG_TIJDEN  E_MG_TIJDEN_tabel[] = {
/*            instellingen (x.y of NG) van de tijden:           */
/*     sg:    MG_TIJD4:  MG_TIJD5:  MG_TIJD6:                   */
/*     SGn;    x.y,       x.y,       x.y,                       */
       SG02,    NG,        NG,        NG,
       SG05,    NG,        NG,        NG,
       STOP};


/*     HiaatTIJDEN tabel                                        */
struct H_TIJDEN  H_TIJDEN_tabel[] = {
/*               instellingen (x.y of NG) van de tijden:        */
/*     sg:       H1e_TIJD:   H2e_TIJD:                          */
/*     SGn,       x.y,        x.y,                              */
       SG02,      2.0,         NG,
       SG05,      2.0,         NG,
       STOP};


/*     SignaalGroep-DETECTIE tabel                              */
struct SG_DETECTIE           SG_DETECTIE_tabel[] = {
/*     D():     type:        sg:     toewijzing:                */
/*     SGn_i,   DP (of DK),  SGn,    AVR + BS_H5p + H1e + H2e,  */
       SG02_1,  DP,          SG02,   AVR + BS_H5p + H1e,
       SG05_1,  DP,          SG05,   AVR + BS_H5p + H1e,
       STOP};


/*
 * =============================================================
 * tijden, klokken en schakelaars
 * =============================================================
 */

/*     TIJDEN tabel                                                   */
struct TIJDEN                 TIJDEN_tabel[] = {
/*     TIJD():                instelling:                             */
/*     SGn_i,                   x.y,                                  */

/*     invoer-parameters t.b.v. filemeetpunt                           */
       t_bezet_D02_2,        3.5,     /* als D langer bezet is -> file   */
       t_bezet_D02_3,        3.5,     /* als D langer bezet is -> file   */
       t_rijden_D02_2,       1.9,     /* als D korter bezet is -> !file  */
       t_rijden_D02_3,       1.9,     /* als D korter bezet is -> !file  */
       t_afvallen_D02_2,    12.0,     /* afvalvertraging filemelding     */
       t_afvallen_D02_3,    12.0,     /* afvalvertraging filemelding     */
       t_bezet_D02_4,        3.5,     /* als D langer bezet is -> file   */
       t_bezet_D02_5,        3.5,     /* als D langer bezet is -> file   */
       t_rijden_D02_4,       1.9,     /* als D korter bezet is -> !file  */
       t_rijden_D02_5,       1.9,     /* als D korter bezet is -> !file  */
       t_afvallen_D02_4,    12.0,     /* afvalvertraging filemelding     */
       t_afvallen_D02_5,    12.0,     /* afvalvertraging filemelding     */
       t_afvalbewaking_02,  60.0,     /* bewaking afvallen file bij !D   */

       t_bezet_D05_2,        3.5,     /* als D langer bezet is -> file   */
       t_bezet_D05_3,        3.5,     /* als D langer bezet is -> file   */
       t_rijden_D05_2,       1.9,     /* als D korter bezet is -> !file  */
       t_rijden_D05_3,       1.9,     /* als D korter bezet is -> !file  */
       t_afvallen_D05_2,    12.0,     /* afvalvertraging filemelding     */
       t_afvallen_D05_3,    12.0,     /* afvalvertraging filemelding     */
       t_afvalbewaking_05,  60.0,     /* bewaking afvallen file bij !D   */

       STOP};


/*     KLOKKEN tabel                                            */
struct KLOKKEN KLOKKEN_tabel[] = {
/*     KL():           1e tijdstip:  2e tijdstip:               */
/*     NAAM,            x.yz,         x.yz,                     */
       STOP};


/*     SCHAKELAAR tabel                                            */
struct SCHAKELAAR SCHAKELAAR_tabel[] = {
/*     SCH():                   instelling:                        */
/*     NAAM,                    AAN (of UIT),                      */
       s_afvalbewaking,         AAN,
       STOP};


/*
 * =============================================================
 * opties voor versnelde realisatie
 * =============================================================
 */

/*     SG gebonden optie: VAA_OP(SGn)                           */
struct SG_OPTIE           VAA_OP_tabel[] = {
/*     optie voor sg:     inhoud van de optie:                  */
/*     SGn,               WAAR (of functie),                    */
       SG02,              WAAR,
       SG05,              WAAR,
       STOP};


/*     SG gebonden optie: PPV_OP(SGn)                           */
struct SG_OPTIE           PPV_OP_tabel[] = {
/*     optie voor sg:     inhoud van de optie:                  */
/*     SGn,               WAAR (of functie),                    */
       SG02,              WAAR,
       SG05,              WAAR,
       STOP};


/*     REGELING tabel                                              */
struct REGELING   REGELING_tabel[] = {
/*     Nummer,  */
            1,
       STOP};

struct FICT_CONFLICT  FICT_CONFLICT_tabel[] = {STOP};
struct SG_BS_H5t          SG_BS_H5t_tabel[] = {STOP};
struct SG_BS_H5ac        SG_BS_H5ac_tabel[] = {STOP};
struct SG_BS_H66          SG_BS_H66_tabel[] = {STOP};
struct WB                        WB_tabel[] = {STOP};
struct E_H_TIJDEN        E_H_TIJDEN_tabel[] = {STOP};
struct SG_RGA                SG_RGA_tabel[] = {STOP};
struct FIETS_VOETG_R  FIETS_VOETG_R_tabel[] = {STOP};
struct SG_MAH3              SG_MAH3_tabel[] = {STOP};
struct SG_PPAH              SG_PPAH_tabel[] = {STOP};
struct SG_WSRH              SG_WSRH_tabel[] = {STOP};
struct EGGPARMS            EGGPARMS_tabel[] = {STOP};
struct EPARMS                EPARMS_tabel[] = {STOP};
struct BK_OPTIE               BO_OP_tabel[] = {STOP};
struct SG_OPTIE               MA_OP_tabel[] = {STOP};
struct SG_BK_OPTIE           PPP_OP_tabel[] = {STOP};
struct SG_OPTIE              MVG_OP_tabel[] = {STOP};
struct SG_OPTIE               TR_OP_tabel[] = {STOP};
struct SG_OPTIE              PPB_OP_tabel[] = {STOP};
struct SG_BK_OPTIE           PPA_OP_tabel[] = {STOP};
struct SG_BK_OPTIE           VNM_OP_tabel[] = {STOP};
struct SG_OPTIE              AFK_OP_tabel[] = {STOP};
struct SG_OPTIE               BL_OP_tabel[] = {STOP};
struct SG_OPTIE              RVG_OP_tabel[] = {STOP};
struct SG_OPTIE              VAG_OP_tabel[] = {STOP};
struct SG_OPTIE              VMG_OP_tabel[] = {STOP};
struct KOPPEL                KOPPEL_tabel[] = {STOP};
